clear all; close all;

%
% --- WAVEWATCH III(R) Version 4.08 ---
% Plotting script for wave tracking results created by ww3_systrk
% Andre van der Westhuysen, Dec 2012
%

%--- User Configurable Parameters ------------------ 
direc = '/export/emc-lw-awesthuy/wd20aw/presentations/WW3_Winterschool_2013/svn/WW3_Winter_School_Jan2013/day_5/tutorial_wavetracking/';
outfile = 'midpac_30m';
tmin = 1;
tmax = 4;
maxpartspaces = 6;
excep = 9999.00;
sysind = [1 2 3 4 5 6]
timeind = [1 2 3 4]
lonlim = [100 275];
latlim = [-10 90];

%Buoy locations
obsloc1 = [360-162.060 24.320]; %NDBC 51101 NW Hawaii
obsloc2 = [360-160.582 23.018]; %NDBC 51003 W Hawaii
obsloc3 = [360-137.464 40.754]; %46006 - SE PAPA - 60nm West of Eureka, CA
%---------------------------------------------------

%----- Read Coordinates
fid = fopen([direc 'sys_coord.ww3']);
clear buffer
%Read coordinates
dummy = fgets(fid);
ysize = str2num(dummy(1:10));
dummy = fgets(fid);
xsize = str2num(dummy(1:10));
dummy = fgets(fid);
xcor = zeros(ysize,xsize);
ycor = zeros(ysize,xsize);
for iy = 1:ysize
    buffer(iy,:) = str2num(fgets(fid));
end
xcor(1:ysize,1:xsize) = buffer((end-ysize+1):end,1:xsize);
clear buffer
dummy = fgets(fid);
for iy = 1:ysize
    buffer(iy,:) = str2num(fgets(fid));
end
ycor(1:ysize,1:xsize) = buffer((end-ysize+1):end,1:xsize);

%----- Read Hs fields of wave systems
fid = fopen([direc 'sys_hs.ww3']);
clear buffer
dummy = fgets(fid);
ysize = str2num(dummy(1:10));
dummy = fgets(fid);
xsize = str2num(dummy(1:10));
for it = 1:tmax
    dummy = fgets(fid);
    timestring{it} = dummy(1:15);
    dummy = fgets(fid);
    partmax(it) = str2num(dummy(1:6));
    for ipart = 1:partmax(it)
       clear buffer
       dummy = fgets(fid);
       dummy = fgets(fid);
       for iy = 1:ysize
          buffer(iy,:) = str2num(fgets(fid));
       end
       hm0(it,ipart,1:ysize,1:xsize) = buffer((end-ysize+1):end,1:xsize);
       hm0(find(hm0==excep)) = NaN;
    end
end
fclose(fid);

%----- Read Tp fields of wave systems
fid = fopen([direc 'sys_tp.ww3']);
clear buffer
dummy = fgets(fid);
ysize = str2num(dummy(1:10));
dummy = fgets(fid);
xsize = str2num(dummy(1:10));
for it = 1:tmax
    dummy = fgets(fid);
    dummy = fgets(fid);
    partmax(it) = str2num(dummy(1:6));
    for ipart = 1:partmax(it)
       clear buffer
       dummy = fgets(fid);
       dummy = fgets(fid);
       for iy = 1:ysize
          buffer(iy,:) = str2num(fgets(fid));
       end
       tp(it,ipart,1:ysize,1:xsize) = buffer((end-ysize+1):end,1:xsize);
       tp(find(tp==excep)) = NaN;
    end
end
fclose(fid);

%----- Read Dir fields of wave systems
fid = fopen([direc 'sys_dir.ww3']);
clear buffer
dummy = fgets(fid);
ysize = str2num(dummy(1:10));
dummy = fgets(fid);
xsize = str2num(dummy(1:10));
for it = 1:tmax
    dummy = fgets(fid);
    dummy = fgets(fid);
    partmax(it) = str2num(dummy(1:6));
    for ipart = 1:partmax(it)
       clear buffer
       dummy = fgets(fid);
       dummy = fgets(fid);
       for iy = 1:ysize
          buffer(iy,:) = str2num(fgets(fid));
       end
       dir(it,ipart,1:ysize,1:xsize) = buffer((end-ysize+1):end,1:xsize);
       dir(find(dir==excep)) = NaN;
    end
end
fclose(fid);

%----- Read Dspr fields of wave systems
fid = fopen([direc 'sys_dspr.ww3']);
clear buffer
dummy = fgets(fid);
ysize = str2num(dummy(1:10));
dummy = fgets(fid);
xsize = str2num(dummy(1:10));
for it = 1:tmax
    dummy = fgets(fid);
    dummy = fgets(fid);
    partmax(it) = str2num(dummy(1:6));
    for ipart = 1:partmax(it)
       clear buffer
       dummy = fgets(fid);
       dummy = fgets(fid);
       for iy = 1:ysize
          buffer(iy,:) = str2num(fgets(fid));
       end
       dspr(it,ipart,1:ysize,1:xsize) = buffer((end-ysize+1):end,1:xsize);
       dspr(find(dir==excep)) = NaN;
    end
end
fclose(fid);

b = load([direc 'coastal_bound_low.mat']);
land_index = [1 2 3 4 5 6 7 8 9 10]; %Main global contours
hawaii_index = [334 474 637 968 1322 1491 1692]; %Big Island, Oahu, Maui, Kauai, Lanai, Molokai, Niihau  

scrsz = get(0,'ScreenSize');
fig = figure('Position',[1 0.20*scrsz(4) 0.5*scrsz(3) 0.70*scrsz(4)]);

%Make movie
for it = tmin:tmax
    scrsz = get(0,'ScreenSize');
    fig = figure('Position',[1 0.20*scrsz(4) 0.5*scrsz(3) 0.90*scrsz(4)]);
    for ipart = 1:length(sysind)
       subplot(maxpartspaces,2,(2*(ipart-1)+1))
       surf(xcor,ycor,squeeze(hm0(it,sysind(ipart),:,:)),'LineStyle','none')
       hold on
       dirx = cos( (270-squeeze(dir(it,sysind(ipart),:,:)))*pi/180 );
       diry = sin( (270-squeeze(dir(it,sysind(ipart),:,:)))*pi/180 );
       quiver3(xcor(1:10:end,1:10:end),ycor(1:10:end,1:10:end),10*ones(size(xcor(1:10:end,1:10:end))), ...
               dirx(1:10:end,1:10:end),diry(1:10:end,1:10:end),0*ones(size(xcor(1:10:end,1:10:end))),'k')
       for indx = 1:length(land_index);
          if indx~=6
             fill3(b.bound(land_index(indx)).x,b.bound(land_index(indx)).y, ...
                   5.*ones(size(b.bound(land_index(indx)).x)),[0.7 0.7 0.7]);
          elseif indx==6
             fill3(b.bound(land_index(indx)).x(1:(end-1)),b.bound(land_index(indx)).y(1:(end-1)), ...
                   5.*ones(size(b.bound(land_index(indx)).x(1:(end-1)))),[0.7 0.7 0.7]);
          end
       end
       for indx = 1:length(hawaii_index);
          fill3(b.bound(hawaii_index(indx)).x,b.bound(hawaii_index(indx)).y, ...
                5.*ones(size(b.bound(hawaii_index(indx)).x)),[0.7 0.7 0.7]);
       end   
       plot3(obsloc1(1),obsloc1(2),9.999,'k+','LineWidth',1.5,'MarkerSize',8); %51101 - NW Hawaii
       text(obsloc1(1)+5,obsloc1(2),9.999,'51101');
       view(2)
       xlim([lonlim(1) lonlim(2)]);
       ylim([latlim(1) latlim(2)]);
       zlim([0 8])
       caxis([0 8])
       colorbar
       title(['Hs (m): ',timestring{it},', isys = ',num2str(sysind(ipart))])
       box on;
       
       subplot(maxpartspaces,2,(2*(ipart-1)+2))
       surf(xcor,ycor,squeeze(tp(it,sysind(ipart),:,:)),'LineStyle','none')
       hold on
       dirx = cos( (270-squeeze(dir(it,sysind(ipart),:,:)))*pi/180 );
       diry = sin( (270-squeeze(dir(it,sysind(ipart),:,:)))*pi/180 );
       quiver3(xcor(1:10:end,1:10:end),ycor(1:10:end,1:10:end),20*ones(size(xcor(1:10:end,1:10:end))), ...
               dirx(1:10:end,1:10:end),diry(1:10:end,1:10:end),0*ones(size(xcor(1:10:end,1:10:end))),'k')
       for indx = 1:length(land_index);
          if indx~=6
             fill3(b.bound(land_index(indx)).x,b.bound(land_index(indx)).y, ...
                   5.*ones(size(b.bound(land_index(indx)).x)),[0.7 0.7 0.7]);
          elseif indx==6
             fill3(b.bound(land_index(indx)).x(1:(end-1)),b.bound(land_index(indx)).y(1:(end-1)), ...
                   5.*ones(size(b.bound(land_index(indx)).x(1:(end-1)))),[0.7 0.7 0.7]);
          end
       end 
       for indx = 1:length(hawaii_index);
          fill3(b.bound(hawaii_index(indx)).x,b.bound(hawaii_index(indx)).y, ...
                5.*ones(size(b.bound(hawaii_index(indx)).x)),[0.7 0.7 0.7]);
       end   
       plot3(obsloc1(1),obsloc1(2),9.999,'k+','LineWidth',1.5,'MarkerSize',8); %51101 - NW Hawaii
       view(2)
       xlim([lonlim(1) lonlim(2)]);
       ylim([latlim(1) latlim(2)]);
       zlim([0 20])
       caxis([0 20])
       colorbar
       title(['Tp (s): ',timestring{it},', isys = ',num2str(sysind(ipart))])   
       box on;
     end
        
    %F(it) = getframe(fig);
    figsize = 15;
    set(gcf,'PaperPosition',[1 0.20 0.7 0.90]*figsize)
    print(gcf,'-dpng','-painters',[direc,outfile,'_',timestring{it},'_sys',num2str(sysind,'%d'),'.png'])
    close all;
end
