clear all; close all;

%
% --- WAVEWATCH III(R) Version 4.08 ---
% Plotting script for wave tracking results created by ww3_systrk
% Andre van der Westhuysen, Dec 2012
%

%--- User Configurable Parameters ------------------ 
direc = '/export/emc-lw-awesthuy/wd20aw/presentations/WW3_Winterschool_2013/svn/WW3_Winter_School_Jan2013/day_5/tutorial_wavetracking/';
outfile = 'midpac_30m_timeseries';
tmin = 1;
tmax = 4;
datelimits = [datenum(2009,11,22,0,0,0) datenum(2009,11,22,3,0,0)];
dateticklimits = [datenum(2009,11,22,0,0,0):1:datenum(2009,11,22,3,0,0)];

locname{1} = 'NDBC 46006  (SE PAPA)'; %SE PAPA - 600NM West of Eureka, CA
locname{2} = 'NDBC 51003 (W Hawaii)'; %W HAWAII 205 NM Southwest of Honolulu, HI
locname{3} = 'NDBC 51000 (N Hawaii)'; %Northern Hawaii
locname{4} = 'NDBC 41048 (W Bermuda)'; %W Bermuda
locname{5} = 'NDBC 62029 (K1 Buoy)'; %K1 Buoy
locname{6} = 'NDBC 13002 (NE Extension)'; %NE Extension
locname{7} = 'NDBC 51101 (NW Hawaii)'; %NW Hawaii
locname{8} = 'NDBC 51100 (N Hawaii)'; %N Hawaii
ioutpnt = 7; %Index of output point to plot
%---------------------------------------------------

%---Read wave tracking output
fid = fopen([direc 'sys_pnt.ww3']);
clear buffer
for i = 1:7
    dummy = fgets(fid);
end

npnts = length(locname);
for it = 1:tmax
    dstr = fgets(fid);
    outdate(it) = datenum(str2num(dstr(8:11)),str2num(dstr(12:13)),str2num(dstr(14:15)), ...
                      str2num(dstr(17:18)),str2num(dstr(19:20)),str2num(dstr(21:22)));
    for ipnt = 1:npnts
       dummy = fgets(fid);
       outlon(ipnt) = str2num(dummy(1:14));
       outlat(ipnt) = str2num(dummy(15:28));
       outpar(it,ipnt,1:10,1) = str2num(dummy(29:168));
       outpar(it,ipnt,1:10,2) = str2num(dummy(169:308));
       outpar(it,ipnt,1:10,3) = str2num(dummy(309:448));
       outpar(it,ipnt,1:10,1) = str2num(dummy(29:168));
       outpar(it,ipnt,1:10,2) = str2num(dummy(169:308));
       outpar(it,ipnt,1:10,3) = str2num(dummy(309:448));
       outpar(find(outpar==0.)) = NaN;
       outpar(find(outpar==0.)) = NaN;
       outpar(find(outpar==0.)) = NaN;
       outpar(find(outpar==999.9999)) = NaN;
       outpar(find(outpar==999.9999)) = NaN;
       outpar(find(outpar==999.9999)) = NaN;
    end
end
fclose(fid);

colvec = ['k','b','r','g','m','c'];
sysarr = [1 2 3 4 5 6];

%--- Comparison plot
figure
subplot(3,1,1)
for isys = 1:length(sysarr)
   plot(outdate(:),outpar(:,ioutpnt,sysarr(isys),1),'o-','Color',colvec(isys),'MarkerSize',6)
   hold on;
end
ylabel(['H_{m0} (m)'],'FontSize',14)
xlim(datelimits);
datetick('x',15,'keeplimits');
lg = legend('Sys 1','Sys 2','Sys 3','Sys 4','Sys 5','Sys 6','Orientation','horizontal','FontSize',14)
set(lg,'Position',[0.22 0.003 0.6 0.06]);
set(gca,'FontSize',14)
title(cell2mat(locname(ioutpnt)),'FontSize',14);
box on;

subplot(3,1,2)
for isys = 1:length(sysarr)
   plot(outdate(:),outpar(:,ioutpnt,sysarr(isys),2),'o-','Color',colvec(isys),'MarkerSize',6)
   hold on;
end
ylabel(['T_p (s)'],'FontSize',14)
xlim(datelimits);
datetick('x',15,'keeplimits');
set(gca,'FontSize',14)
box on;

subplot(3,1,3)
for isys = 1:length(sysarr)
   plot(outdate(:),outpar(:,ioutpnt,sysarr(isys),3),'o-','Color',colvec(isys),'MarkerSize',6)
   hold on;
end
xlabel('Time during 2009/11/22 (UTC)','FontSize',14)
ylabel(['Dir (deg)'],'FontSize',14)
xlim(datelimits);
datetick('x',15,'keeplimits');
set(gca,'FontSize',14)
box on;

figname = cell2mat(locname(ioutpnt));
figsize = 15;
set(gcf,'PaperPosition',[1 0.20 0.7 0.70]*figsize)
print(gcf,'-dpng',[direc outfile '.png'])


